@@ -6,6 +6,7 @@ pub mod claim_certificate;
 pub mod extend_certificate;
 pub mod invalidate_certificate;
 pub mod revoke_certificate;
+pub mod revoke_certificate_v2;
 pub mod use_certificate;
 pub mod set_original_mint;
 
@@ -17,5 +18,6 @@ pub use claim_certificate::*;
 pub use extend_certificate::*;
 pub use invalidate_certificate::*;
 pub use revoke_certificate::*;
+pub use revoke_certificate_v2::*;
 pub use use_certificate::*;
 pub use set_original_mint::*;
