@@ -8,9 +8,7 @@ use anchor_spl::{
 
 #[derive(Accounts)]
 pub struct SetOriginalMintCtx<'info> {
-    #[account(mut, constraint = certificate.state == CertificateState::Issued as u8,
-        seeds = [CERTIFICATE_SEED.as_bytes(), certificate.mint.as_ref()], bump = certificate.bump
-    )]
+    #[account(mut, constraint = certificate.state == CertificateState::Issued as u8)]
     pub certificate: Box<Account<'info, Certificate>>,
     pub original_mint_holder: Signer<'info>,
     #[account(constraint = original_mint_token_account.owner == original_mint_holder.key() && original_mint_token_account.amount > 0 @ ErrorCode::InvalidOriginalMintAccount)]
