@@ -11,8 +11,7 @@ pub struct UseCertificateCtx<'info> {
     #[account(mut, constraint = certificate.state == CertificateState::Claimed as u8
         && (certificate.expiration == None || Clock::get().unwrap().unix_timestamp < certificate.expiration.unwrap())
         && (certificate.max_usages == None || certificate.usages < certificate.max_usages.unwrap()) 
-        @ ErrorCode::CannotUse,
-        seeds = [CERTIFICATE_SEED.as_bytes(), certificate.mint.as_ref()], bump = certificate.bump
+        @ ErrorCode::CannotUse
     )]
     pub certificate: Account<'info, Certificate>,
     #[account(constraint = user.key() == recipient_token_account.owner @ ErrorCode::InvalidOwnership)]
